package com.yonge.cooleshow.admin.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;

import com.yonge.cooleshow.biz.dal.support.PageUtil;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.cooleshow.common.page.PageInfo;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import com.yonge.cooleshow.biz.dal.vo.VipCardRecordVo;
import com.yonge.cooleshow.biz.dal.dto.search.VipCardRecordSearch;
import com.yonge.cooleshow.biz.dal.entity.VipCardRecord;
import com.yonge.cooleshow.biz.dal.service.VipCardRecordService;

@RestController
@RequestMapping("/vipCardRecord")
@Api(value = "购买会员卡记录表", tags = "购买会员卡记录表")
public class VipCardRecordController extends BaseController {

    @Autowired
    private VipCardRecordService vipCardRecordService;

	/**
     * 查询单条
     */
    @GetMapping("/detail/{id}")
    @ApiOperation(value = "详情", notes = "传入id")
    public HttpResponseResult<VipCardRecordVo> detail(@PathVariable("id") Long id) {
    	return succeed(vipCardRecordService.detail(id));
	}
    
    /**
     * 查询分页
     */
    @PostMapping("/page")
    @ApiOperation(value = "查询分页", notes = "传入vipCardRecordSearch")
    public HttpResponseResult<PageInfo<VipCardRecordVo>> page(@RequestBody VipCardRecordSearch query) {
		IPage<VipCardRecordVo> pages = vipCardRecordService.selectPage(PageUtil.getPage(query), query);
        return succeed(PageUtil.pageInfo(pages));
	}
    
    /**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperation(value = "新增", notes = "传入vipCardRecord")
	public HttpResponseResult save(@Valid @RequestBody VipCardRecord vipCardRecord) {
    	return status(vipCardRecordService.save(vipCardRecord));
	}
    
    /**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperation(value = "修改", notes = "传入vipCardRecord")
	public HttpResponseResult update(@Valid @RequestBody VipCardRecord vipCardRecord) {
        return status(vipCardRecordService.updateById(vipCardRecord));
	}
    
    /**
	 * 新增或修改
	 */
    @PostMapping("/submit")
    @ApiOperation(value = "新增或修改", notes = "传入vipCardRecord")
	public HttpResponseResult submit(@Valid @RequestBody VipCardRecord vipCardRecord) {
        return status(vipCardRecordService.saveOrUpdate(vipCardRecord));
    }

 	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public HttpResponseResult remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
        if (StringUtil.isEmpty(ids)) {
			return failed("参数不能为空");
		}
		return status(vipCardRecordService.removeByIds(StringUtil.toLongList(ids)));
	}
}