package com.yonge.cooleshow.teacher.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.dto.req.WithdrawalReq;
import com.yonge.cooleshow.biz.dal.dto.search.TeacherWithdrawalSearch;
import com.yonge.cooleshow.biz.dal.service.UserWithdrawalService;
import com.yonge.cooleshow.biz.dal.support.PageUtil;
import com.yonge.cooleshow.biz.dal.vo.UserWithdrawalVo;
import com.yonge.cooleshow.biz.dal.vo.res.WithdrawalInfoRes;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.cooleshow.common.exception.BizException;
import com.yonge.cooleshow.common.page.PageInfo;
import com.yonge.toolset.utils.date.DateUtil;
import com.yonge.toolset.utils.string.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Calendar;
import java.util.Date;

@RestController
@RequestMapping("/userWithdrawal")
@Api(value = "用户账户提现表", tags = "用户账户提现表")
public class UserWithdrawalController extends BaseController {
    @Autowired
    private UserWithdrawalService userWithdrawalService;
    @Autowired
    private SysUserFeignService sysUserFeignService;

    @PostMapping("/getWithdrawalInfo")
    @ApiOperation(value = "查询提现页面信息")
    public HttpResponseResult<WithdrawalInfoRes> getWithdrawalInfo() {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null || null == user.getId()) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        return userWithdrawalService.getWithdrawalInfo(user.getId());
    }

    @PostMapping("/withdrawal")
    @ApiOperation(value = "用户提现")
    public HttpResponseResult<Boolean> withdrawal(@Valid @RequestBody WithdrawalReq withdrawalReq) {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null || null == user.getId()) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        return userWithdrawalService.withdrawal(user.getId(), withdrawalReq);
    }

    @PostMapping("/withdrawalPage")
    @ApiOperation(value = "提现记录")
    public HttpResponseResult<PageInfo<UserWithdrawalVo>> withdrawalPage(@RequestBody TeacherWithdrawalSearch withdrawalSearch) {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null || null == user.getId()) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }
        withdrawalSearch.setUserId(user.getId());
        if (StringUtil.isEmpty(withdrawalSearch.getSearchDate())) {
            withdrawalSearch.setSearchDate(DateUtil.format(new Date(), "yyyy-MM"));
        }
        try {
            Calendar calendar = Calendar.getInstance();
            String[] classDateSp = withdrawalSearch.getSearchDate().split("-");
            calendar.set(Integer.parseInt(classDateSp[0]), Integer.parseInt(classDateSp[1]) - 1, 1, 0, 0, 0);
            withdrawalSearch.setStartTime(calendar.getTime());
            withdrawalSearch.setEndTime(DateUtil.dayEnd(DateUtil.getLastDayOfMonth(calendar.getTime())));
        } catch (Exception e) {
            throw new BizException("查询时间格式不正确 [" + withdrawalSearch.getSearchDate() + "]");
        }
        IPage<UserWithdrawalVo> pages = userWithdrawalService.selectPage(PageUtil.getPage(withdrawalSearch), withdrawalSearch);
        return succeed(PageUtil.pageInfo(pages));
    }

}